==> vanoma_api_utils-0.30.0-py3-none-any.whl: vanoma_api_utils/http.py <==
import json
import logging
import requests
from typing import Any, Dict, List, Union
from requests import Response


class Client(object):
    def __init__(self) -> None:
        self.timeout = 20  # 20 seconds to match java client
        self.session = requests.Session()

    def get(self, url: str, headers: Dict[str, Any] = {}) -> Response:
        return self._request("GET", url, None, headers)

    def post(
        self, url: str, data: Dict[str, Any], headers: Dict[str, Any] = {}
    ) -> Response:
        return self._request("POST", url, data, headers)

    def patch(
        self,
        url: str,
        data: Union[Dict[str, Any], List[Any]],
        headers: Dict[str, Any] = {},
    ) -> Response:
        """Accecpts data as a list to support application/json-patch+json content type."""
        return self._request("PATCH", url, data, headers)

    def delete(self, url: str, headers: Dict[str, Any] = {}) -> Response:
        return self._request("DELETE", url, None, headers)

    def _request(
        self,
        method: str,
        url: str,
        data: Union[Dict[str, Any], List[Any], None],
        headers: Dict[str, Any],
    ) -> Response:
        response = self.session.request(method, url, json=data, headers=headers)

        if not response.ok:
            # Using the same logging format as what we use in java http client to simplify searching logs.
            logging.error(
                f"Unexpected response code from: {method} {url} {response.status_code}. RequestBody={json.dumps(data)}. ResponseBody={response.content.decode()}."
            )

        return response


client = Client()

==> vanoma_api_utils-0.38.0-py3-none-any.whl: vanoma_api_utils/http.py <==
import json
import logging
import requests
from typing import Any, Dict, Union
from requests import Response


class Client(object):
    def __init__(self) -> None:
        self.timeout = 20  # 20 seconds to match java client
        self.session = requests.Session()

    def get(self, url: str, headers: Dict[str, Any] = None) -> Response:
        return self._request("GET", url, None, headers)

    def post(
        self, url: str, data: Dict[str, Any], headers: Dict[str, Any] = None
    ) -> Response:
        return self._request("POST", url, data, headers)

    def put(
        self, url: str, data: Dict[str, Any], headers: Dict[str, Any] = None
    ) -> Response:
        return self._request("PUT", url, data, headers)

    def patch(
        self, url: str, data: Dict[str, Any], headers: Dict[str, Any] = None
    ) -> Response:
        return self._request("PATCH", url, data, headers)

    def delete(self, url: str, headers: Dict[str, Any] = None) -> Response:
        return self._request("DELETE", url, None, headers)

    def _request(
        self,
        method: str,
        url: str,
        data: Union[Dict[str, Any], None],
        headers: Union[Dict[str, Any], None],
    ) -> Response:
        response = self.session.request(method, url, json=data, headers=headers)

        if not response.ok:
            # Using the same logging format as what we use in java http client to simplify searching logs.
            logging.error(
                f"Unexpected response code from: {method} {url} {response.status_code}. RequestBody={json.dumps(data)}. ResponseBody={response.content.decode()}."
            )

        return response


client = Client()
